Serializers
-------------

.. autoclass:: pai.serializers.SerializerBase
   :members:
   :show-inheritance:

.. autoclass:: pai.serializers.JsonSerializer
   :members:
   :show-inheritance:

.. autoclass:: pai.serializers.TensorFlowSerializer
   :members:
   :show-inheritance:

.. autoclass:: pai.serializers.PyTorchSerializer
   :members:
   :show-inheritance:
